diff --git a/typo3/sysext/backend/Classes/ContextMenu/ItemProviders/PageProvider.php b/typo3/sysext/backend/Classes/ContextMenu/ItemProviders/PageProvider.php
index 9161c269e733a5528ee1f3bcff8a6f01eafbcc56..88bb32cf4b21a81d35cab312d87ba7c25a1a9717 100644
--- a/typo3/sysext/backend/Classes/ContextMenu/ItemProviders/PageProvider.php
+++ b/typo3/sysext/backend/Classes/ContextMenu/ItemProviders/PageProvider.php
@@ -532,9 +532,8 @@ class PageProvider extends RecordProvider
     }
 
     /**
      * Checks if user has access to this column
      * and the page doktype is lower than 200 (exclude sys_folder, ...)
      * and it contains given value
      */
     protected function canBeToggled(string $fieldName, int $value): bool
     {
@@ -542,7 +541,7 @@ class PageProvider extends RecordProvider
             return false;
         }
         if (!empty($GLOBALS['TCA'][$this->table]['columns'][$fieldName]['exclude'])
-            && $this->record['doktype'] <= PageRepository::DOKTYPE_SPACER
+            && !$this->isExcludedDoktype()
             && $this->backendUser->check('non_exclude_fields', $this->table . ':' . $fieldName)
             && $this->backendUser->check('tables_modify', $this->table)
         ) {
@@ -532,9 +532,8 @@ class PageProvider extends RecordProvider
 
     /**
-     * Checks if user has access to this column
-     * and the page doktype is lower than 200 (exclude sys_folder, ...)
-     * and it contains given value
+     * Checks if user has access to this column, the doktype
+     * is not excluded and that it contains the given value.
      */
     protected function canBeToggled(string $fieldName, int $value): bool